@@ -1,13 +1,12 @@
 package Date::Baha::i;
 
 use strict;
-use vars qw($VERSION); $VERSION = '0.04';
+use vars qw($VERSION); $VERSION = '0.05';
 use base qw(Exporter);
 use vars qw(@EXPORT @EXPORT_OK);
 @EXPORT = @EXPORT_OK = qw(
     cycles
     date
-    day_of_week
     days
     days_of_the_week
     greg_to_bahai
@@ -23,6 +22,7 @@ use Date::Calc qw(
     Delta_Days
     Timezone
 );
+use Lingua::EN::Numbers::Ordinate;
 
 # Set constants {{{
 use constant FACTOR => 19;
@@ -135,11 +135,15 @@ sub date {
 
     # Loop through all the official months, less two.
     for my $n (0 .. FACTOR - 2) {
-        my ($my_y, $my_m, $my_d) = ninteen_days ($year, $m, $d);
+        my ($my_y, $my_m, $my_d) = _ninteen_days ($year, $m, $d);
 
         # Have we found our month?
-        if ($found = in_month_span ($month, $day, $m, $d, $my_m, $my_d)) {
-            $bahai_day = delta_month_days ($m, $d - 1, $year, $month, $day);
+        if ($found = _in_month_span (
+                $month, $day, $m, $d, $my_m, $my_d)
+        ) {
+            $bahai_day = _delta_month_days (
+                $m, $d - 1, $year, $month, $day
+            );
             $bahai_month = $n;
             last;
         }
@@ -150,17 +154,21 @@ sub date {
 
     # If we haven't found our month, check 'Ala.
     if (!$found &&
-        ($found = in_month_span (
-            $month, $day, MARCH, LAST_START_DAY, MARCH, YEAR_START_DAY - 1
-         ))
+        ($found = _in_month_span (
+            $month, $day, MARCH, LAST_START_DAY, MARCH, YEAR_START_DAY - 1)
+        )
     ) { 
-        $bahai_day = delta_month_days (MARCH, LAST_START_DAY - 1, $year, $month, $day);
+        $bahai_day = _delta_month_days (
+            MARCH, LAST_START_DAY - 1, $year, $month, $day
+        );
         $bahai_month = FACTOR - 1;
     }   
 
     # If we still didn't find a month, it is Ayyam-i-Ha!
     unless ($found) {
-        $bahai_day = delta_month_days (FEBRUARY, LEAP_START_DAY - 1, $year, $month, $day);
+        $bahai_day = _delta_month_days (
+            FEBRUARY, LEAP_START_DAY - 1, $year, $month, $day
+        );
         $bahai_month = -1;
     }
 
@@ -180,7 +188,7 @@ sub greg_to_bahai {
 
 # Helper functions {{{
 # The Baha'i week starts on Saturday.
-sub day_of_week {
+sub _day_of_week {
     my ($y, $m, $d) = @_;
     my $standard = Day_of_Week ($y, $m, $d);
     $standard++;
@@ -189,7 +197,7 @@ sub day_of_week {
 
 # Compute the number of days between consecutive months.
 # In our case, it's, "How many days are we into this Baha'i month?"
-sub delta_month_days {
+sub _delta_month_days {
     my ($m1, $d1, $y2, $m2, $d2) = @_;
     # If Dec-Jan, get the next year.
     my $y1 = $m1 == 12 && $m2 == 1 ? $y2 + 1 : $y2;
@@ -197,7 +205,7 @@ sub delta_month_days {
 }
 
 # What month are we in?
-sub in_month_span {
+sub _in_month_span {
     my ($m, $d, $m1, $d1, $m2, $d2) = @_;
     # If the months are the same, just check the day range.
     if ($m1 == $m2 && $m == $m1) {
@@ -214,7 +222,7 @@ sub in_month_span {
 }
 
 # Return  the standard date ninteen days hence.
-sub ninteen_days {
+sub _ninteen_days {
     my ($y, $m, $d) = @_;
     return Add_Delta_Days($y, $m, $d - 1, FACTOR)
 }
@@ -226,7 +234,7 @@ sub _build_date {
     @date{qw(month day)} = ($new_month, $new_day);
 
     # Set the day of the week.
-    $date{dow} = day_of_week ($year, $month, $day);
+    $date{dow} = _day_of_week ($year, $month, $day);
     $date{dow_name} = (DOW_NAME)[$date{dow}];
     $date{dow}++;
 
@@ -254,9 +262,30 @@ sub _build_date {
     # ($D_y,$D_m,$D_d, $Dh,$Dm,$Ds, $dst) = Timezone ();
     $date{timezone} = (Timezone ())[3];
 
-    return %date;
+    return wantarray ? %date : _as_string (%date);
 }
 
+# kull_i_shay'th kull-i-shay,
+# cycle'th vahid (cycle_name),
+# cycle_year'th year of the vahid, 
+# year'th year (year_name),
+# month'th month of the year (month_name),
+# day'th day of the month (day_name),
+# dow'th day of the week (dow_name),
+# with time zone offset of timezone
+sub _as_string {
+    my %date = @_;
+    my $date =
+        ordinate ($date{kull_i_shay}) . ' kull-i-shay, ' .
+        ordinate ($date{cycle})       . " vahid ($date{cycle_name}), " .
+        ordinate ($date{cycle_year})  . ' year of the vahid, ' .
+        ordinate ($date{year})        . " year ($date{year_name}), " .
+        ordinate ($date{month})       . " month of the year ($date{month_name}), " .
+        ordinate ($date{day})         . " day of the month ($date{day_name}), " .
+        ordinate ($date{dow})         . " day of the week ($date{dow_name}), " .
+        "with time zone offset of $date{timezone} hours";
+    return $date;
+}
 # }}}
 
 1;
@@ -271,19 +300,21 @@ Date::Baha::i - Compute the numeric and named Baha'i date.
   use Date::Baha'i;
 
   %bahai_date = date ();
+  $bahai_date = date ();
 
   %bahai_date = greg_to_bahai ($year, $month, $day);
+  $bahai_date = greg_to_bahai ($year, $month, $day);
 
   @ret = cycles ();
-  @ret = day_of_week ();
+  @ret = years ();
+  @ret = months ();
   @ret = days ();
   @ret = days_of_the_week ();
   @ret = holy_days ();
-  @ret = years ();
 
 =head1 ABSTRACT
 
-This package outputs a (numeric and named) Baha'i date from a standard system time stamp.
+This package outputs a (numeric and named) Baha'i date from a standard system time stamp or year, month, day triple.
 
 =head1 DESCRIPTION
 
@@ -338,25 +369,25 @@ Each cycle of nineteen years is called a Vahid. Nineteen cycles constitute a per
 
 The names of the years in each cycle are: 
 
-  1.  Alif - The Letter "A"
-  2.  Ba - The letter "B"
-  3.  Ab - Father
-  4.  Dal - The letter "D"
-  5.  Bab - Gate
-  6.  Vav - The letter "V"
-  7.  Abad - Eternity
-  8.  Jad - Generosity
-  9.  Baha - Splendour
-  10. Hubb - Love
+  1.  Alif   - The Letter "A"
+  2.  Ba     - The letter "B"
+  3.  Ab     - Father
+  4.  Dal    - The letter "D"
+  5.  Bab    - Gate
+  6.  Vav    - The letter "V"
+  7.  Abad   - Eternity
+  8.  Jad    - Generosity
+  9.  Baha   - Splendour
+  10. Hubb   - Love
   11. Bahhaj - Delightful
-  12. Javab - Answer
-  13. Ahad - Single
+  12. Javab  - Answer
+  13. Ahad   - Single
   14. Vahhab - Bountiful
-  15. Vidad - Affection
-  16. Badi - Beginning
-  17. Bahi - Luminous
-  18. Abha - Most Luminous
-  19. Vahid - Unity
+  15. Vidad  - Affection
+  16. Badi   - Beginning
+  17. Bahi   - Luminous
+  18. Abha   - Most Luminous
+  19. Vahid  - Unity
 
 There are eleven Holy Days which Baha'is celebrate. On [many] of these days, all work should cease. They are listed in chronological order according to the Baha'i calendar.
 
@@ -430,15 +461,15 @@ Text taken from
 
 L<http://www.moonwise.co.uk/year/159bahai.htm>
 
-=head1 FUNCTIONS
+=head1 EXPORTED FUNCTIONS
 
 =head2 date
 
   %bahai_date = date ([time])
 
-This function returns a hash of the date names and numbers from a system time() stamp.
+This function returns a hash of the Baha'i date names and numbers from a system or user provided time () stamp.
 
-The hash returned has these keys:
+In a scalar context, this function returns a string sentence with the numeric and named Baha'i date.  In an array context, it returns a hash with the following keys:
 
   kull_i_shay
   cycle
@@ -458,47 +489,73 @@ The hash returned has these keys:
 
   %bahai_date = greg_to_bahai ($year, $month, $day);
 
+Compute the Baha'i date from a Gregorian year, month, day triple.
+
+In a scalar context, this function returns a string sentence with the numeric and named Baha'i date.  In an array context, it returns the date () hash (described above).
+
 =head2 cycles
 
+  @cycles = cycles ();
+
 Return the 19 cycle names as an array.
 
 =head2 years
 
+  @years = years ();
+
 Return the 19 year names as an array.
 
 =head2 months
 
-Return the 19 month names as an array, along with  the intercalary days ("Ayyam-i-Ha") as the last element.
+  @months = months ();
+
+Return the 19 month names as an array, along with the intercalary days ("Ayyam-i-Ha") as the last element.
 
 =head2 days
 
+  @days = days ();
+
 Return the 19 day names as an array.
 
+=head2 days_of_the_week
+
+  @days = days_of_the_week ();
+
+Return the 7 day-of-the-week names as an array.
+
 =head2 holy_days
 
+  @days = holy_days ();
+
 Return the holy days as a hash where the keys are the holy day names and the values are array references.  These array references are composed of two or three elements, where the first is the month, the second is the day, and the third is the (optional) number of days observed.  These dates are currently in standard (non-Baha'i) format.
 
 =head1 DEPENDENCIES
 
 L<Date::Calc>
 
+L<Lingua::EN::Numbers::Ordinate>
+
 =head1 TODO
 
-Overload localtime() and gmtime?
+Overload localtime() and gmtime().
 
-Convert between Gregorian dates/Unix timestamps and Baha'i dates.
+Also, add the current holy day to the date, if the day is on one.
+
+Convert to Gregorian dates and Unix time stamps from Baha'i dates.
 
 Base the date computation on the time of day (the Baha'i day begins at Sunset).
 
 Output unicode.
 
+Add a next_holy_day () function?
+
 =head1 DEDICATION
 
 Hi Kirsten  : )
 
 =head1 AUTHOR
 
-Gene Boggs, E<lt>cpan@ology.netE<gt>
+Gene Boggs E<lt>cpan@ology.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
